.. reference:
=====================
Reference
=====================

.. raw:: html

   <hr>

Getting Started
---------------

These guides are suitable for a general user audience and should typically be read by every user. They include information
on installing and using the library for, at a minimum, simple use cases. These guides are also useful for familiarizing yourself
with the core classes and types encountered in ``pyXMIP``.


Basic Usage
'''''''''''

Our "Hello World" documentation; worth a read for any user who wants to use the package.

- :ref:`overview`
- :ref:`install`
- :ref:`source_data`
- :ref:`databases`
- :ref:`cross_referencing`

Visualizing Results
'''''''''''''''''''

Guides for the different visualization options available as part of the library.

- :ref:`plotting`

Advanced Usage
--------------

These documents recount in greater detail many of the more complex aspects of ``pyXMIP`` usage. Users who have more complex
usage needs or are required to build custom classes / software should familiarize themselves with the topics presented here.

.. raw:: html

   <hr>

Statistics
''''''''''

In depth discussions of the various statistical methodologies used across the library.

- :ref:`poisson_mapping`
- :ref:`PSF_modeling`

Expanding Available Datatypes
'''''''''''''''''''''''''''''

Discussions about stretching the available types and structures to their maximum by taking advantage of backend concepts.

- :ref:`schema`


Backend
-------

Documentation for the nuts and bolts aspects of the code including logging, configuration, and more.

.. raw:: html

   <hr>

- :ref:`configuration`
- :ref:`logging`
